@@ -90,8 +90,10 @@ class AbstractSamGeneration(RevPySam, ABC):
         else:
             self._site = None
 
-        self.check_resource_data(resource)
-        self.set_resource_data(resource, meta)
+        # let children pass in None resource
+        if resource is not None:
+            self.check_resource_data(resource)
+            self.set_resource_data(resource, meta)
 
     @classmethod
     def _get_res(cls, res_df, output_request):
@@ -264,7 +266,8 @@ class AbstractSamGeneration(RevPySam, ABC):
         return self['capacity_factor'] / 100
 
     def cf_profile(self):
-        """Get hourly capacity factor (frac) profile in orig timezone.
+        """Get hourly capacity factor (frac) profile in local timezone.
+        See self.outputs attribute for collected output data in UTC.
 
         Returns
         -------
@@ -295,7 +298,8 @@ class AbstractSamGeneration(RevPySam, ABC):
         return self['kwh_per_kw']
 
     def gen_profile(self):
-        """Get power generation profile (orig timezone) in kW.
+        """Get power generation profile (local timezone) in kW.
+        See self.outputs attribute for collected output data in UTC.
 
         Returns
         -------
@@ -306,8 +310,9 @@ class AbstractSamGeneration(RevPySam, ABC):
         return np.array(self['gen'], dtype=np.float32)
 
     def collect_outputs(self, output_lookup=None):
-        """
-        Collect SAM gen output_request. Rolls outputs to UTC if appropriate.
+        """Collect SAM output_request, convert timeseries outputs to UTC, and
+        save outputs to self.outputs property.
+
 
         Parameters
         ----------
@@ -356,7 +361,6 @@ class AbstractSamGeneration(RevPySam, ABC):
             lcoe.assign_inputs()
             lcoe.execute()
             lcoe.collect_outputs()
-            lcoe.outputs_to_utc_arr()
             self.outputs.update(lcoe.outputs)
 
         elif so_out_reqs is not None:
@@ -365,7 +369,6 @@ class AbstractSamGeneration(RevPySam, ABC):
             so.assign_inputs()
             so.execute()
             so.collect_outputs()
-            so.outputs_to_utc_arr()
             self.outputs.update(so.outputs)
 
     def run(self):
@@ -375,7 +378,6 @@ class AbstractSamGeneration(RevPySam, ABC):
         self.assign_inputs()
         self.execute()
         self.collect_outputs()
-        self.outputs_to_utc_arr()
 
     @classmethod
     def reV_run(cls, points_control, res_file, site_df,
@@ -469,6 +471,36 @@ class AbstractSamGeneration(RevPySam, ABC):
 class AbstractSamSolar(AbstractSamGeneration, ABC):
     """Base Class for Solar generation from SAM"""
 
+    @staticmethod
+    def agg_albedo(time_index, albedo):
+        """Aggregate a timeseries of albedo data to monthly values w len 12 as
+        required by pysam Pvsamv1
+
+        Tech spec from pysam docs:
+        https://nrel-pysam.readthedocs.io/en/master/modules/Pvsamv1.html
+        #PySAM.Pvsamv1.Pvsamv1.SolarResource.albedo
+
+        Parameters
+        ----------
+        time_index : pd.DatetimeIndex
+            Timeseries solar resource datetimeindex
+        albedo : list
+            Timeseries Albedo data to be aggregated. Should be 0-1 and likely
+            hourly or less.
+
+        Returns
+        -------
+        monthly_albedo : list
+            1D list of monthly albedo values with length 12
+        """
+        monthly_albedo = np.zeros(12).tolist()
+        albedo = np.array(albedo)
+        for month in range(1, 13):
+            m = np.where(time_index.month == month)[0]
+            monthly_albedo[int(month - 1)] = albedo[m].mean()
+
+        return monthly_albedo
+
     def set_resource_data(self, resource, meta):
         """Set NSRDB resource data arrays.
 
@@ -545,12 +577,13 @@ class AbstractSamSolar(AbstractSamGeneration, ABC):
         time_index = self.ensure_res_len(time_index, time_index)
         resource['minute'] = time_index.minute
         resource['hour'] = time_index.hour
-        resource['year'] = time_index.year
         resource['month'] = time_index.month
+        resource['year'] = time_index.year
         resource['day'] = time_index.day
 
         if 'albedo' in resource:
-            self['albedo'] = resource.pop('albedo')
+            self['albedo'] = self.agg_albedo(
+                time_index, resource.pop('albedo'))
 
         self['solar_resource_data'] = resource
 
@@ -663,7 +696,8 @@ class AbstractSamPv(AbstractSamSolar, ABC):
         return self['capacity_factor'] / 100
 
     def cf_profile(self):
-        """Get hourly capacity factor (frac) profile in orig timezone.
+        """Get hourly capacity factor (frac) profile in local timezone.
+        See self.outputs attribute for collected output data in UTC.
 
         NOTE: PV capacity factor is the AC power production / the DC nameplate
 
@@ -677,8 +711,9 @@ class AbstractSamPv(AbstractSamSolar, ABC):
         return self.gen_profile() / self.sam_sys_inputs['system_capacity']
 
     def gen_profile(self):
-        """Get AC inverter power generation profile (orig timezone) in kW.
+        """Get AC inverter power generation profile (local timezone) in kW.
         This is an alias of the "ac" SAM output variable.
+        See self.outputs attribute for collected output data in UTC.
 
         Returns
         -------
@@ -689,7 +724,8 @@ class AbstractSamPv(AbstractSamSolar, ABC):
         return self.ac()
 
     def ac(self):
-        """Get AC inverter power generation profile (orig timezone) in kW.
+        """Get AC inverter power generation profile (local timezone) in kW.
+        See self.outputs attribute for collected output data in UTC.
 
         Returns
         -------
@@ -701,7 +737,8 @@ class AbstractSamPv(AbstractSamSolar, ABC):
 
     def dc(self):
         """
-        Get DC array power generation profile (orig timezone) in kW.
+        Get DC array power generation profile (local timezone) in kW.
+        See self.outputs attribute for collected output data in UTC.
 
         Returns
         -------
@@ -714,7 +751,8 @@ class AbstractSamPv(AbstractSamSolar, ABC):
     def clipped_power(self):
         """
         Get the clipped DC power generated behind the inverter
-        (orig timezone) in kW.
+        (local timezone) in kW.
+        See self.outputs attribute for collected output data in UTC.
 
         Returns
         -------
@@ -733,7 +771,8 @@ class AbstractSamPv(AbstractSamSolar, ABC):
         """Get the executed default pysam object."""
 
     def collect_outputs(self, output_lookup=None):
-        """Collect SAM gen output_request.
+        """Collect SAM output_request, convert timeseries outputs to UTC, and
+        save outputs to self.outputs property.
 
         Parameters
         ----------
@@ -797,7 +836,8 @@ class PvSamv1(AbstractSamPv):
     PYSAM = PySamDetailedPv
 
     def ac(self):
-        """Get AC inverter power generation profile (orig timezone) in kW.
+        """Get AC inverter power generation profile (local timezone) in kW.
+        See self.outputs attribute for collected output data in UTC.
 
         Returns
         -------
@@ -809,7 +849,8 @@ class PvSamv1(AbstractSamPv):
 
     def dc(self):
         """
-        Get DC array power generation profile (orig timezone) in kW.
+        Get DC array power generation profile (local timezone) in kW.
+        See self.outputs attribute for collected output data in UTC.
 
         Returns
         -------
@@ -838,7 +879,8 @@ class TcsMoltenSalt(AbstractSamSolar):
 
     def cf_profile(self):
         """Get absolute value hourly capacity factor (frac) profile in
-        orig timezone.
+        local timezone.
+        See self.outputs attribute for collected output data in UTC.
 
         Returns
         -------
@@ -1150,6 +1192,7 @@ class WindPower(AbstractSamGeneration):
 
         # add resource data to self.data and clear
         self['wind_resource_data'] = data_dict
+        self['wind_resource_model_choice'] = 0
 
     @staticmethod
     def default():
@@ -1162,6 +1205,93 @@ class WindPower(AbstractSamGeneration):
         return DefaultWindPower.default()
 
 
+class WindPowerPD(WindPower):
+    """WindPower analysis with wind speed/direction joint probabilty
+    distrubtion input"""
+
+    def __init__(self, ws_edges, wd_edges, wind_dist,
+                 meta, sam_sys_inputs,
+                 site_sys_inputs=None, output_request=None):
+        """Initialize a SAM generation object for windpower with a
+        speed/direction joint probability distribution.
+
+        Parameters
+        ----------
+        ws_edges : np.ndarray
+            1D array of windspeed (m/s) values that set the bin edges for the
+            wind probability distribution. Same len as wind_dist.shape[0] + 1
+        wd_edges : np.ndarray
+            1D array of winddirections (deg) values that set the bin edges
+            for the wind probability dist. Same len as wind_dist.shape[1] + 1
+        wind_dist : np.ndarray
+            2D array probability distribution of (windspeed, winddirection).
+        meta : pd.DataFrame | pd.Series
+            Meta data corresponding to the resource input for the single
+            location. Should include values for latitude, longitude, elevation,
+            and timezone.
+        sam_sys_inputs : dict
+            Site-agnostic SAM system model inputs arguments.
+        site_sys_inputs : dict
+            Optional set of site-specific SAM system inputs to complement the
+            site-agnostic inputs.
+        output_request : list
+            Requested SAM outputs (e.g., 'cf_mean', 'annual_energy',
+            'cf_profile', 'gen_profile', 'energy_yield', 'ppa_price',
+            'lcoe_fcr').
+        """
+
+        # make sure timezone and elevation are in the meta data
+        meta = self.tz_elev_check(sam_sys_inputs, site_sys_inputs, meta)
+
+        # don't pass resource to base class,
+        # set in concrete generation classes instead
+        super().__init__(None, meta, sam_sys_inputs,
+                         site_sys_inputs=site_sys_inputs,
+                         output_request=output_request,
+                         drop_leap=False)
+
+        # Set the site number using meta data
+        if hasattr(meta, 'name'):
+            self._site = meta.name
+        else:
+            self._site = None
+
+        self.set_resource_data(ws_edges, wd_edges, wind_dist)
+
+    def set_resource_data(self, ws_edges, wd_edges, wind_dist):
+        """Send wind PD to pysam
+
+        Parameters
+        ----------
+        ws_edges : np.ndarray
+            1D array of windspeed (m/s) values that set the bin edges for the
+            wind probability distribution. Same len as wind_dist.shape[0] + 1
+        wd_edges : np.ndarray
+            1D array of winddirections (deg) values that set the bin edges
+            for the wind probability dist. Same len as wind_dist.shape[1] + 1
+        wind_dist : np.ndarray
+            2D array probability distribution of (windspeed, winddirection).
+        """
+
+        assert len(ws_edges) == wind_dist.shape[0] + 1
+        assert len(wd_edges) == wind_dist.shape[1] + 1
+
+        wind_dist /= wind_dist.sum()
+
+        # SAM wants the midpoints of the sample bins
+        ws_points = ws_edges[:-1] + np.diff(ws_edges) / 2
+        wd_points = wd_edges[:-1] + np.diff(wd_edges) / 2
+
+        wd_points, ws_points = np.meshgrid(wd_points, ws_points)
+        vstack = (ws_points.flatten(),
+                  wd_points.flatten(),
+                  wind_dist.flatten())
+        wrd = np.vstack(vstack).T.tolist()
+
+        self['wind_resource_model_choice'] = 2
+        self['wind_resource_distribution'] = wrd
+
+
 class MhkWave(AbstractSamGeneration):
     """Class for Wave generation from SAM
     """
